pytilities.types._numerictypemeta — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.types »

# pytilities.types._numerictypemeta

class `pytilities.types._numerictypemeta.` `_NumericTypeMeta`
  `__instancecheck__`(instance)
  `__subclasscheck__`(subclass)

    Note: returns false for a string as we can’t tell whether it’s numeric. Try to avoid subclass checks of numbers with strings.

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.types »